<?php

return [
    'Names' => [
        'AD' => 'Andorra',
        'AE' => 'Emiriah Arab Bersatu',
        'AF' => 'Afghanistan',
        'AG' => 'Antigua dan Barbuda',
        'AI' => 'Anguilla',
        'AL' => 'Albania',
        'AM' => 'Armenia',
        'AO' => 'Angola',
        'AQ' => 'Antartika',
        'AR' => 'Argentina',
        'AS' => 'Samoa Amerika',
        'AT' => 'Austria',
        'AU' => 'Australia',
        'AW' => 'Aruba',
        'AX' => 'Kepulauan Aland',
        'AZ' => 'Azerbaijan',
        'BA' => 'Bosnia dan Herzegovina',
        'BB' => 'Barbados',
        'BD' => 'Bangladesh',
        'BE' => 'Belgium',
        'BF' => 'Burkina Faso',
        'BG' => 'Bulgaria',
        'BH' => 'Bahrain',
        'BI' => 'Burundi',
        'BJ' => 'Benin',
        'BL' => 'St. Barthelemy',
        'BM' => 'Bermuda',
        'BN' => 'Brunei',
        'BO' => 'Bolivia',
        'BQ' => 'Belanda Caribbean',
        'BR' => 'Brazil',
        'BS' => 'Bahamas',
        'BT' => 'Bhutan',
        'BV' => 'Pulau Bouvet',
        'BW' => 'Botswana',
        'BY' => 'Belarus',
        'BZ' => 'Belize',
        'CA' => 'Kanada',
        'CC' => 'Kepulauan Cocos (Keeling)',
        'CD' => 'Congo - Kinshasa',
        'CF' => 'Republik Afrika Tengah',
        'CG' => 'Congo - Brazzaville',
        'CH' => 'Switzerland',
        'CI' => 'Cote d’Ivoire',
        'CK' => 'Kepulauan Cook',
        'CL' => 'Chile',
        'CM' => 'Cameroon',
        'CN' => 'China',
        'CO' => 'Colombia',
        'CR' => 'Costa Rica',
        'CU' => 'Cuba',
        'CV' => 'Cape Verde',
        'CW' => 'Curacao',
        'CX' => 'Pulau Krismas',
        'CY' => 'Cyprus',
        'CZ' => 'Czechia',
        'DE' => 'Jerman',
        'DJ' => 'Djibouti',
        'DK' => 'Denmark',
        'DM' => 'Dominica',
        'DO' => 'Republik Dominica',
        'DZ' => 'Algeria',
        'EC' => 'Ecuador',
        'EE' => 'Estonia',
        'EG' => 'Mesir',
        'EH' => 'Sahara Barat',
        'ER' => 'Eritrea',
        'ES' => 'Sepanyol',
        'ET' => 'Ethiopia',
        'FI' => 'Finland',
        'FJ' => 'Fiji',
        'FK' => 'Kepulauan Falkland',
        'FM' => 'Micronesia',
        'FO' => 'Kepulauan Faroe',
        'FR' => 'Perancis',
        'GA' => 'Gabon',
        'GB' => 'United Kingdom',
        'GD' => 'Grenada',
        'GE' => 'Georgia',
        'GF' => 'Guiana Perancis',
        'GG' => 'Guernsey',
        'GH' => 'Ghana',
        'GI' => 'Gibraltar',
        'GL' => 'Greenland',
        'GM' => 'Gambia',
        'GN' => 'Guinea',
        'GP' => 'Guadeloupe',
        'GQ' => 'Guinea Khatulistiwa',
        'GR' => 'Greece',
        'GS' => 'Kepulauan Georgia Selatan & Sandwich Selatan',
        'GT' => 'Guatemala',
        'GU' => 'Guam',
        'GW' => 'Guinea Bissau',
        'GY' => 'Guyana',
        'HK' => 'Hong Kong SAR China',
        'HM' => 'Kepulauan Heard & McDonald',
        'HN' => 'Honduras',
        'HR' => 'Croatia',
        'HT' => 'Haiti',
        'HU' => 'Hungary',
        'ID' => 'Indonesia',
        'IE' => 'Ireland',
        'IL' => 'Israel',
        'IM' => 'Isle of Man',
        'IN' => 'India',
        'IO' => 'Wilayah Lautan Hindi British',
        'IQ' => 'Iraq',
        'IR' => 'Iran',
        'IS' => 'Iceland',
        'IT' => 'Itali',
        'JE' => 'Jersey',
        'JM' => 'Jamaica',
        'JO' => 'Jordan',
        'JP' => 'Jepun',
        'KE' => 'Kenya',
        'KG' => 'Kyrgyzstan',
        'KH' => 'Kemboja',
        'KI' => 'Kiribati',
        'KM' => 'Comoros',
        'KN' => 'Saint Kitts dan Nevis',
        'KP' => 'Korea Utara',
        'KR' => 'Korea Selatan',
        'KW' => 'Kuwait',
        'KY' => 'Kepulauan Cayman',
        'KZ' => 'Kazakhstan',
        'LA' => 'Laos',
        'LB' => 'Lubnan',
        'LC' => 'Saint Lucia',
        'LI' => 'Liechtenstein',
        'LK' => 'Sri Lanka',
        'LR' => 'Liberia',
        'LS' => 'Lesotho',
        'LT' => 'Lithuania',
        'LU' => 'Luxembourg',
        'LV' => 'Latvia',
        'LY' => 'Libya',
        'MA' => 'Maghribi',
        'MC' => 'Monaco',
        'MD' => 'Moldova',
        'ME' => 'Montenegro',
        'MF' => 'Saint Martin',
        'MG' => 'Madagaskar',
        'MH' => 'Kepulauan Marshall',
        'MK' => 'Macedonia Utara',
        'ML' => 'Mali',
        'MM' => 'Myanmar (Burma)',
        'MN' => 'Mongolia',
        'MO' => 'Macau SAR China',
        'MP' => 'Kepulauan Mariana Utara',
        'MQ' => 'Martinique',
        'MR' => 'Mauritania',
        'MS' => 'Montserrat',
        'MT' => 'Malta',
        'MU' => 'Mauritius',
        'MV' => 'Maldives',
        'MW' => 'Malawi',
        'MX' => 'Mexico',
        'MY' => 'Malaysia',
        'MZ' => 'Mozambique',
        'NA' => 'Namibia',
        'NC' => 'New Caledonia',
        'NE' => 'Niger',
        'NF' => 'Pulau Norfolk',
        'NG' => 'Nigeria',
        'NI' => 'Nicaragua',
        'NL' => 'Belanda',
        'NO' => 'Norway',
        'NP' => 'Nepal',
        'NR' => 'Nauru',
        'NU' => 'Niue',
        'NZ' => 'New Zealand',
        'OM' => 'Oman',
        'PA' => 'Panama',
        'PE' => 'Peru',
        'PF' => 'Polinesia Perancis',
        'PG' => 'Papua New Guinea',
        'PH' => 'Filipina',
        'PK' => 'Pakistan',
        'PL' => 'Poland',
        'PM' => 'Saint Pierre dan Miquelon',
        'PN' => 'Kepulauan Pitcairn',
        'PR' => 'Puerto Rico',
        'PS' => 'Wilayah Palestin',
        'PT' => 'Portugal',
        'PW' => 'Palau',
        'PY' => 'Paraguay',
        'QA' => 'Qatar',
        'RE' => 'Reunion',
        'RO' => 'Romania',
        'RS' => 'Serbia',
        'RU' => 'Rusia',
        'RW' => 'Rwanda',
        'SA' => 'Arab Saudi',
        'SB' => 'Kepulauan Solomon',
        'SC' => 'Seychelles',
        'SD' => 'Sudan',
        'SE' => 'Sweden',
        'SG' => 'Singapura',
        'SH' => 'Saint Helena',
        'SI' => 'Slovenia',
        'SJ' => 'Svalbard dan Jan Mayen',
        'SK' => 'Slovakia',
        'SL' => 'Sierra Leone',
        'SM' => 'San Marino',
        'SN' => 'Senegal',
        'SO' => 'Somalia',
        'SR' => 'Surinam',
        'SS' => 'Sudan Selatan',
        'ST' => 'Sao Tome dan Principe',
        'SV' => 'El Salvador',
        'SX' => 'Sint Maarten',
        'SY' => 'Syria',
        'SZ' => 'Eswatini',
        'TC' => 'Kepulauan Turks dan Caicos',
        'TD' => 'Chad',
        'TF' => 'Wilayah Selatan Perancis',
        'TG' => 'Togo',
        'TH' => 'Thailand',
        'TJ' => 'Tajikistan',
        'TK' => 'Tokelau',
        'TL' => 'Timor-Leste',
        'TM' => 'Turkmenistan',
        'TN' => 'Tunisia',
        'TO' => 'Tonga',
        'TR' => 'Turkiye',
        'TT' => 'Trinidad dan Tobago',
        'TV' => 'Tuvalu',
        'TW' => 'Taiwan',
        'TZ' => 'Tanzania',
        'UA' => 'Ukraine',
        'UG' => 'Uganda',
        'UM' => 'Kepulauan Terpencil A.S.',
        'US' => 'Amerika Syarikat',
        'UY' => 'Uruguay',
        'UZ' => 'Uzbekistan',
        'VA' => 'Kota Vatican',
        'VC' => 'Saint Vincent dan Grenadines',
        'VE' => 'Venezuela',
        'VG' => 'Kepulauan Virgin British',
        'VI' => 'Kepulauan Virgin A.S.',
        'VN' => 'Vietnam',
        'VU' => 'Vanuatu',
        'WF' => 'Wallis dan Futuna',
        'WS' => 'Samoa',
        'YE' => 'Yaman',
        'YT' => 'Mayotte',
        'ZA' => 'Afrika Selatan',
        'ZM' => 'Zambia',
        'ZW' => 'Zimbabwe',
    ],
];
